Content class
Constructors
-
Content({required String type, required dynamic data, List<
CarouselItem> ? carouselItems}) -
Content.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
carouselItems
→ List<
CarouselItem> ? -
final
- data → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCarousel → bool
-
no setter
- isHtml → bool
-
no setter
- isImage → bool
-
no setter
- isVideo → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited